==> OpenCL-0.7.7.tgz: OpenCL-0.7.7/include/filter.h <==
/*************************************************
* Filter Header File                             *
* (C) 1999-2001 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_FILTER_H__
#define OPENCL_FILTER_H__

#include <opencl/opencl.h>

namespace OpenCL {

/*************************************************
* Filter Base Class                              *
*************************************************/
class Filter
   {
   public:
      struct Invalid_Port_Number : public Invalid_Argument
         { Invalid_Port_Number() :
              Invalid_Argument("Filter: Invalid port number was used") {} };
      virtual ~Filter() {}
   protected:
      virtual void send(const byte[], u32bit);
      void send(byte input) { send(&input, 1); }
      void attach(Filter*);
      void set_port(u32bit) throw(Invalid_Port_Number);
      u32bit total_ports()  const { return port_count; }
      u32bit current_port() const { return port_num; }
      Filter(u32bit = 1);
   private:
      friend class Pipe;
      friend class Fork;
      friend void destroy(Filter*&);
      Filter(const Filter&) : port_count(0) {}
      void operator=(const Filter&) {}
      virtual void write(const byte[], u32bit) = 0;
      virtual void final() {}
      virtual void close();
      void add(const class SecureQueue&, Filter*);
      Filter* get_next() const { if(next) return next[port_num]; return 0; }
      const u32bit port_count;
      SecureVector<byte> write_queue;
      Filter** next;
      u32bit port_num;
   };

/*************************************************
* Destroy this Filter and it's children          *
*************************************************/
void destroy(Filter*&);

}

#endif

==> OpenCL-0.7.8.tgz: OpenCL-0.7.8/include/filter.h <==
/*************************************************
* Filter Header File                             *
* (C) 1999-2002 The OpenCL Project               *
*************************************************/

#ifndef OPENCL_FILTER_H__
#define OPENCL_FILTER_H__

#include <opencl/opencl.h>

namespace OpenCL {

/*************************************************
* Filter Base Class                              *
*************************************************/
class Filter
   {
   public:
      virtual void write(const byte[], u32bit) = 0;
      virtual void start_msg() {}
      virtual void end_msg() {}
      virtual bool attachable() { return true; }
      void new_msg();
      void finish_msg();
      virtual ~Filter() {}
   protected:
      virtual void send(const byte[], u32bit);
      void send(byte input) { send(&input, 1); }
      void attach(Filter*);
      u32bit total_ports()  const { return port_count; }
      u32bit current_port() const { return port_num; }
      void set_port_count(u32bit);
      void set_port(u32bit);
      u32bit owns() const { return filter_owns; }
      void set_owns(u32bit o) { filter_owns = o; }
      Filter(u32bit = 1);
   private:
      friend class Pipe;
      friend class Fork;
      friend void destroy(Filter*&);
      Filter(const Filter&) : port_count(0) {}
      void operator=(const Filter&) {}

      void add(const class SecureQueue&, Filter*);
      Filter* get_next() const { if(next) return next[port_num]; return 0; }
      SecureVector<byte> write_queue;
      Filter** next;
      u32bit port_count, port_num, filter_owns;
   };

/*************************************************
* Destroy this Filter and it's children          *
*************************************************/
void destroy(Filter*&);

}

#endif
